@@ -24,6 +24,7 @@
 #
 """Bring in all of the public Alfred interface into this module."""
 import importlib
+
 # pylint: disable=g-bad-import-order
 
 from .modules import *
@@ -32,5 +33,6 @@ from .fusion import *
 from .dl.torch.common import print_shape
 from .utils.log import logger
 from .dl.torch.common import device
+from .utils.progress import pbar, prange
 
-globals().update(importlib.import_module('alfred').__dict__)
\ No newline at end of file
+globals().update(importlib.import_module("alfred").__dict__)
