@@ -21,12 +21,12 @@ class ConcatenatedDataset(SliceableDataset):
 
     def __init__(self, *datasets):
         if len(datasets) == 0:
-            raise ValueError('At least one dataset is required')
+            raise ValueError("At least one dataset is required")
         self._datasets = datasets
         self._keys = datasets[0].keys
         for dataset in datasets[1:]:
             if not dataset.keys == self._keys:
-                raise ValueError('All datasets should have the same keys')
+                raise ValueError("All datasets should have the same keys")
 
     def __len__(self):
         return sum(len(dataset) for dataset in self._datasets)
@@ -42,4 +42,4 @@ class ConcatenatedDataset(SliceableDataset):
             if index < len(dataset):
                 return dataset.get_example_by_keys(index, key_indices)
             index -= len(dataset)
-        raise IndexError
\ No newline at end of file
+        raise IndexError
