@@ -23,8 +23,10 @@
 #
 import torch
 
+
 def one_hot(tensor, depth, dim=-1, on_value=1.0, dtype=torch.float32):
     tensor_onehot = torch.zeros(
-        *list(tensor.shape), depth, dtype=dtype, device=tensor.device)
+        *list(tensor.shape), depth, dtype=dtype, device=tensor.device
+    )
     tensor_onehot.scatter_(dim, tensor.unsqueeze(dim).long(), on_value)
     return tensor_onehot
