@@ -27,7 +27,5 @@ import torch
 class GroupNorm(torch.nn.GroupNorm):
     def __init__(self, num_channels, num_groups, eps=1e-5, affine=True):
         super().__init__(
-            num_groups=num_groups,
-            num_channels=num_channels,
-            eps=eps,
-            affine=affine)
+            num_groups=num_groups, num_channels=num_channels, eps=eps, affine=affine
+        )
