@@ -21,9 +21,14 @@
 # specific language governing permissions and limitations
 # under the License.
 #
-from .checkpoint import (latest_checkpoint, restore,
-                         restore_latest_checkpoints,
-                         restore_models, save, save_models,
-                         try_restore_latest_checkpoints)
+from .checkpoint import (
+    latest_checkpoint,
+    restore,
+    restore_latest_checkpoints,
+    restore_models,
+    save,
+    save_models,
+    try_restore_latest_checkpoints,
+)
 from .common import create_folder
 from .optim import MixedPrecisionWrapper
