@@ -14,10 +14,10 @@ def mkdir(path):
 def mkfile(filePath):
     pipfile = "[global]\ntrusted-host=mirrors.aliyun.com\nindex-url=http://mirrors.aliyun.com/pypi/simple/"
     if os.path.exists(filePath):
-        if str(input("File exist!Cover?(Y/N))")).upper() == 'N':
+        if str(input("File exist!Cover?(Y/N))")).upper() == "N":
             print("Not Cover.")
             return
-    with open(filePath, 'w') as fp:
+    with open(filePath, "w") as fp:
         fp.write(pipfile)
     print("Write finish.")
 
@@ -26,12 +26,12 @@ def change_pypi_source():
     systype = platform.system()
     print("System type: " + systype)
     if systype == "Windows":
-        path = os.path.join(os.getenv('HOMEPATH'), 'pip')
+        path = os.path.join(os.getenv("HOMEPATH"), "pip")
         mkdir(path)
-        mkfile(os.path.join(path, 'pip.ini'))
+        mkfile(os.path.join(path, "pip.ini"))
     elif systype == "Linux" or systype == "Darwin":
-        path = os.path.join(os.path.expandvars('$HOME'), ".pip")
+        path = os.path.join(os.path.expandvars("$HOME"), ".pip")
         mkdir(path)
-        mkfile(os.path.join(path, 'pip.conf'))
+        mkfile(os.path.join(path, "pip.conf"))
     else:
         print("System type: " + systype + " Not Support!")
