@@ -45,7 +45,7 @@ try:
     CACHED_RESULT_PATH = xdg_cache_home() / "starcli.json"
 except Exception as e:
     CACHED_RESULT_PATH = "/tmp/starcli.json"
-print(f"temp cached path: {CACHED_RESULT_PATH}")
+# print(f"temp cached path: {CACHED_RESULT_PATH}")
 CACHE_EXPIRATION = 1  # Minutes
 API_URL = "https://api.github.com/search/repositories"
 
@@ -426,7 +426,6 @@ def grid_layout(repos):
 
     panels = []
     for repo in repos:
-
         stats = get_stats(repo)
         # '\n' added here as it would group both text and new line together
         # hence if date_range isn't present the new line will also not be displayed
