@@ -10,9 +10,9 @@ class HTMLFormatter:
     Convert lines in the HTML.
     """
 
-    format = 'html'
+    format = "html"
 
     @staticmethod
     def write(lines):
-        md = markdown(''.join(lines), output_format='html')
-        return f'<html>\n<head></head>\n<body>\n{md}\n</body>\n</html>'.encode()
+        md = markdown("".join(lines), output_format="html")
+        return f"<html>\n<head></head>\n<body>\n{md}\n</body>\n</html>".encode()
