@@ -36,6 +36,7 @@ import pickle
 import os.path
 import sys
 import numpy as np
+
 if sys.version_info[0] == 2:
     import xml.etree.cElementTree as ET
 else:
@@ -43,9 +44,8 @@ else:
 import glob
 
 
-
 def gather_labels(anno_dir):
-    all_labels = glob.glob(os.path.join(anno_dir, '*.xml'))
+    all_labels = glob.glob(os.path.join(anno_dir, "*.xml"))
     all_names = []
     all_obj_num = 0
     xmls_without_boxes = []
@@ -53,13 +53,13 @@ def gather_labels(anno_dir):
     cls_num_map = dict()
     for label in all_labels:
         if i % 500 == 0:
-            print('parsing [{}/{}] {}'.format(i, len(all_labels), label))
+            print("parsing [{}/{}] {}".format(i, len(all_labels), label))
         i += 1
         root = ET.parse(label).getroot()
         one_sample_obj_num = 0
-        for obj in root.iter('object'):
+        for obj in root.iter("object"):
             one_sample_obj_num += 1
-            name = obj.find('name').text
+            name = obj.find("name").text
             if name in cls_num_map.keys():
                 cls_num_map[name] += 1
             else:
@@ -69,13 +69,13 @@ def gather_labels(anno_dir):
         if one_sample_obj_num == 0:
             xmls_without_boxes.append(label)
         all_obj_num += one_sample_obj_num
-    print('Done. summary...')
-    print('all {} classes.'.format(len(all_names)))
+    print("Done. summary...")
+    print("all {} classes.".format(len(all_names)))
     print(all_names)
     # we also read xmls with empty boxes
-    print('\nclass boxes statistic as: {}'.format(cls_num_map))
+    print("\nclass boxes statistic as: {}".format(cls_num_map))
     if len(xmls_without_boxes) > 0:
-        print('\nalso, we found these files without any detections, you can consider remove it:')
+        print(
+            "\nalso, we found these files without any detections, you can consider remove it:"
+        )
         print(xmls_without_boxes)
-
-
