@@ -1,4 +1,3 @@
-
 import importlib
 from yacs.config import CfgNode as CN
 import argparse
@@ -8,7 +7,7 @@ class Config:
     @classmethod
     def load_from_args(cls):
         parser = argparse.ArgumentParser()
-        parser.add_argument('--cfg', type=str, default='config/base.yml')
+        parser.add_argument("--cfg", type=str, default="config/base.yml")
         parser.add_argument("opts", default=None, nargs=argparse.REMAINDER)
         args = parser.parse_args()
         return cls.load(filename=args.cfg, opts=args.opts)
@@ -35,15 +34,15 @@ class Config:
 
     @staticmethod
     def print(cfg):
-        print('[Info] --------------')
-        print('[Info] Configuration:')
-        print('[Info] --------------')
+        print("[Info] --------------")
+        print("[Info] Configuration:")
+        print("[Info] --------------")
         print(cfg)
 
 
 def load_object(module_name, module_args):
-    module_path = '.'.join(module_name.split('.')[:-1])
+    module_path = ".".join(module_name.split(".")[:-1])
     module = importlib.import_module(module_path)
-    name = module_name.split('.')[-1]
+    name = module_name.split(".")[-1]
     obj = getattr(module, name)(**module_args)
     return obj
