@@ -9,6 +9,7 @@ Matplotlib.PLT -> OpenCV
 """
 from PIL import Image
 import numpy as np
+import cv2
 
 
 def cv2pil(image, inplace=True):
@@ -26,12 +27,6 @@ def cv2pil(image, inplace=True):
     return new_image
 
 
-def pil2cv(image):
-    new_image = np.array(image, dtype=np.uint8)
-    if new_image.ndim == 2:
-        pass
-    elif new_image.shape[2] == 3:
-        new_image = new_image[:, :, ::-1]
-    elif new_image.shape[2] == 4:
-        new_image = new_image[:, :, [2, 1, 0, 3]]
-    return new_image
\ No newline at end of file
+def pil2cv(pil_image):
+    new_image = cv2.cvtColor(np.array(pil_image), cv2.COLOR_RGB2BGR)
+    return new_image
