@@ -15,11 +15,11 @@ class Timer(object):
 
     def __init__(self, name: str):
         self.name = name
-        self.total_time = 0.
+        self.total_time = 0.0
         self.calls = 0
-        self.start_time = 0.
-        self.diff = 0.
-        self.average_time = 0.
+        self.start_time = 0.0
+        self.diff = 0.0
+        self.average_time = 0.0
 
     def tic(self):
         # using time.time instead of time.clock because time time.clock
@@ -37,15 +37,14 @@ class Timer(object):
             return self.diff
 
     def clear(self):
-        self.total_time = 0.
+        self.total_time = 0.0
         self.calls = 0
-        self.start_time = 0.
-        self.diff = 0.
-        self.average_time = 0.
+        self.start_time = 0.0
+        self.diff = 0.0
+        self.average_time = 0.0
 
 
 class TimerManager(ABC):
-
     def __init__(self, timer_names: Union[List[str], str]):
         self.timer_names = timer_names
         self.tpls = []
@@ -58,11 +57,11 @@ class TimerManager(ABC):
     def collect_avg(self):
         for tn in self.timer_names:
             obj = getattr(self, tn)
-            print(f'{obj.name}: {obj.average_time*1000:.3f}ms')
-        print('')
+            print(f"{obj.name}: {obj.average_time*1000:.3f}ms")
+        print("")
 
 
-'''
+"""
 
 timers = create_some_timers(['det', 'mesh', 'reg'])
 
@@ -78,7 +77,7 @@ timers.mesh.toc()
 
 timers.collect_avg()
 
-'''
+"""
 
 
 class ATimer:
@@ -97,12 +96,13 @@ class ATimer:
 
     @classmethod
     def report(cls):
-        header = ['', 'Time(ms)']
+        header = ["", "Time(ms)"]
         contents = []
         for key, val in cls.records.items():
             contents.append(
-                ['{:20s}'.format(key), '{:.2f}'.format(sum(val)/len(val))])
-        print(tabulate.tabulate(contents, header, tablefmt='fancy_grid'))
+                ["{:20s}".format(key), "{:.2f}".format(sum(val) / len(val))]
+            )
+        print(tabulate.tabulate(contents, header, tablefmt="fancy_grid"))
 
     def __init__(self, name, silent=False):
         self.name = name
@@ -115,13 +115,49 @@ class ATimer:
 
     def __exit__(self, exc_type, exc_value, exc_tb):
         end = time.time()
-        ATimer.records[self.name].append((end-self.start)*1000)
+        ATimer.records[self.name].append((end - self.start) * 1000)
         if not self.silent:
-            t = (end - self.start)*1000
+            t = (end - self.start) * 1000
             if t > 1000:
-                print('-> [{:20s}]: {:5.1f}s'.format(self.name, t/1000))
-            elif t > 1e3*60*60:
-                print('-> [{:20s}]: {:5.1f}min'.format(self.name, t/1e3/60))
+                print("-> [{:20s}]: {:5.1f}s".format(self.name, t / 1000))
+            elif t > 1e3 * 60 * 60:
+                print("-> [{:20s}]: {:5.1f}min".format(self.name, t / 1e3 / 60))
             else:
                 print('-> [{:20s}]: {:5.1f}ms'.format(self.name,
                       (end-self.start)*1000))
+
+
+
+class TimerManagerDynamic(ABC):
+
+    def __init__(self):
+        self.tpls = []
+    
+    def set_timer_start_now(self, name):
+        setattr(self, name, Timer(name))
+        self.tpls.append(name)
+    
+    def tic_on_timer(self, name):
+        getattr(self, name).tic()
+    
+    def toc_on_timer(self, name):
+        cost = getattr(self, name).toc()
+        return cost
+
+    def collect_avg(self):
+        for tn in self.timer_names:
+            obj = getattr(self, tn)
+            print(f'{obj.name}: {obj.average_time*1000:.3f}ms')
+        print('')
+
+global my_timer
+my_timer = TimerManagerDynamic()
+
+def time_start(name: str):
+    my_timer.set_timer_start_now(name)
+    my_timer.tic_on_timer(name)
+
+def time_stop(name:str):
+    c = my_timer.toc_on_timer(name)
+    print(f'[time]: ({name}) cost: {c}')
+    return c
